# Function to perform a simulation according to the ESD modeling
# approach based on the output from the 'ESD_analysis' function,
# requiring the following input:
# parameters    object returned from the 'ESD_analysis' function
# n_sim         number of simulations required
ESD_simulation <- function(parameters, n_sim) {
  
  # Extract the Weibull Shape and Scale parameters from the parameters object
  pars_shape <- parameters[str_detect(string=names(parameters), pattern="Shape")];
  pars_scale <- parameters[str_detect(string=names(parameters), pattern="Scale")];
  
  # Remove 'Shape.' and 'Scale.' from the vector names so the parameters
  # can be extracted from the vector more easily
  names(pars_shape) <- str_remove(string=names(pars_shape), pattern="Shape.");
  names(pars_scale) <- str_remove(string=names(pars_scale), pattern="Scale.");
  
  # Determine the events to simulate
  events <- sort(names(pars_shape));
  
  # Perform the simulation for each event separately
  sim <- sapply(events, function(e) rweibull(n=n_sim, shape=pars_shape[e], scale=pars_scale[e]));
  
  # Determine the lowest time-to-event, i.e. the event to occur
  sim_time <- apply(sim, 1, min);
  
  # Determine which event corresponds to the lowest time-to-event
  sim_event <- colnames(sim)[apply(sim, 1, which.min)];
  
  # Format the simulation in a data.frame
  sim_out <- data.frame(Time=sim_time, Event=sim_event);
  
  # Return the simulation object
  return(sim_out);
  
}