# Function to perform a simulation according to the ESPD modeling
# approach based on the output from the 'ESPD_analysis' function,
# requiring the following input:
# parameters    object returned from the 'ESPD_analysis' function
# n_sim         number of simulations required
ESPD_simulation <- function(parameters, n_sim) {
  
  # Extract the Weibull Shape and Scale parameters from the parameters object
  pars_shape <- parameters[str_detect(string=names(parameters), pattern="Shape")];
  pars_scale <- parameters[str_detect(string=names(parameters), pattern="Scale")];
  pars_prob <- parameters[str_detect(string=names(parameters), pattern="Prob")];
  
  # Remove 'Shape.' and 'Scale.' from the vector names so the parameters
  # can be extracted from the vector more easily
  names(pars_shape) <- str_remove(string=names(pars_shape), pattern="Shape.");
  names(pars_scale) <- str_remove(string=names(pars_scale), pattern="Scale.");
  names(pars_prob) <- str_remove(string=names(pars_prob), pattern="Prob.");
  
  # Determine the events to simulate
  events <- sort(names(pars_prob));
  
  # Simulate events to occur
  sim_event <- sapply(1:n_sim, function(i) events[which(runif(1)<cumsum(pars_prob))[1]]);
  
  # Simulate the corresponding time to events
  sim_time <- sapply(sim_event, function(e) rweibull(n=1, shape=pars_shape[e], scale=pars_scale[e]));
  
  # Format the simulation in a data.frame
  sim_out <- data.frame(Time=sim_time, Event=sim_event);
  
  # Return the simulation object
  return(sim_out);
  
}