# Function to perform a simulation according to the MDR modeling
# approach based on the output from the 'MDR_analysis' function,
# requiring the following input:
# parameters    object returned from the 'MDR_analysis' function
# n_sim         number of simulations required
MDR_simulation <- function(parameters, n_sim) {
  
  # Extract the Weibull Shape and Scale parameters from the parameters object
  pars_mixture <- parameters$mixture;
  pars_shape <- pars_mixture[str_detect(string=names(pars_mixture), pattern="Shape")];
  pars_scale <- pars_mixture[str_detect(string=names(pars_mixture), pattern="Scale")];
  pars_prob <- pars_mixture[str_detect(string=names(pars_mixture), pattern="Prob")];
  
  # Simulate the time-to-events
  sim_time <- rweibullmix(n=n_sim, lambda=pars_prob, shape=pars_shape, scale=pars_scale);
  
  # Estimate the event-probabilities corresponding to the simulated times
  sim_probs <- predict(parameters$regmod, newdata=data.frame(X=sim_time), "probs");
  
  # Determine the events to simulate
  sim_event <- colnames(sim_probs)[apply(sim_probs, 1, function(probs) which(runif(1)<cumsum(probs))[1])];
  
  # Format the simulation in a data.frame
  sim_out <- data.frame(Time=sim_time, Event=sim_event);
  
  # Return the simulation object
  return(sim_out);
  
}