# Function to perform a simulation according to the UDR modeling
# approach based on the output from the 'UDR_analysis' function,
# requiring the following input:
# parameters    object returned from the 'UDR_analysis' function
# n_sim         number of simulations required
UDR_simulation <- function(parameters, n_sim) {
  
  # Extract the Weibull Shape and Scale parameters from the parameters object
  pars_distribution <- parameters$distribution;
  pars_shape <- pars_distribution[str_detect(string=names(pars_distribution), pattern="Shape")];
  pars_scale <- pars_distribution[str_detect(string=names(pars_distribution), pattern="Scale")];

  # Simulate the time-to-events
  sim_time <- rweibull(n=n_sim, shape=pars_shape, scale=pars_scale);
  
  # Estimate the event-probabilities corresponding to the simulated times
  sim_probs <- predict(parameters$regmod, newdata=data.frame(X=sim_time), "probs");
  
  # Determine the events to simulate
  sim_event <- colnames(sim_probs)[apply(sim_probs, 1, function(probs) which(runif(1)<cumsum(probs))[1])];
  
  # Format the simulation in a data.frame
  sim_out <- data.frame(Time=sim_time, Event=sim_event);
  
  # Return the simulation object
  return(sim_out);
  
}