# Function that represents the density function according to
# the cause-specific hazards function, requiring inputs:
# t   vector of time points at which the function is to be evaluated
# k   vector of Weibull shape parameter
# p   vector of Weibull rate parameter
# i   event for which the functions needs to be evaluated
cs_dens <- function(t, k, p, i){
  
  # Determine number of competing events and sample size
  n.events <- length(k);
  n.obs <- length(t);
  
  # Transform the time points, shape parameter, and rate parameter 
  # into matrices, so that matrix calculations can be performed
  tt <- matrix(data=t, nrow=n.obs, ncol=n.events, byrow=F);
  kk <- matrix(data=k, nrow=n.obs, ncol=n.events, byrow=T);
  pp <- matrix(data=p, nrow=n.obs, ncol=n.events, byrow=T);
  
  # Evaluate the hazard function for event i
  hz <- haz(tt[,i], kk[,i], pp[,i]);
  
  # Obtain the survival probabilties
  sv <- apply(1 - pweibull(q=tt, shape=kk, scale=1/pp), 1, prod);
  
  # Calculate and return the density
  return(hz*sv);
}
